"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const meta_1 = require("../meta");
const fs = require('fs');
const path = require('path');
const deepmerge = require('deepmerge');
const recommended = require('./recommended');
const document = require('./document');
const parseSeverityLut = [
    'disable',
    'warn',
    'error',
];
function parseSeverity(value) {
    if (typeof value === 'number') {
        return value;
    }
    else {
        return parseSeverityLut.indexOf(value.toLowerCase());
    }
}
class Config {
    constructor(options) {
        this.config = {
            extends: [],
            rules: {},
        };
        this.mergeInternal(options || {});
        this.metaTable = null;
        this.rootDir = this.findRootDir();
        const self = this;
        this.config.extends.forEach(function (ref) {
            const base = Config.fromFile(ref);
            self.config = base.mergeInternal(self.config);
        });
        this.transformers = this.precompileTransformers(this.config.transform || {});
    }
    static empty() {
        return new Config();
    }
    static fromObject(options) {
        return new Config(options);
    }
    static fromFile(filename) {
        switch (filename) {
            case 'htmlvalidate:recommended': return Config.fromObject(recommended);
            case 'htmlvalidate:document': return Config.fromObject(document);
        }
        const json = require(filename);
        for (const key of ['extends', 'elements']) {
            if (!json[key])
                continue;
            json[key] = json[key].map((ref) => {
                return Config.expandRelative(ref, path.dirname(filename));
            });
        }
        return new Config(json);
    }
    static defaultConfig() {
        return new Config({
            extends: [],
            rules: {},
            transform: [],
        });
    }
    merge(rhs) {
        return new Config(this.mergeInternal(rhs.config));
    }
    getMetaTable() {
        if (this.metaTable) {
            return this.metaTable;
        }
        this.metaTable = new meta_1.MetaTable();
        const source = this.config.elements || ['html5'];
        const root = path.resolve(__dirname, '..', '..');
        for (const entry of source) {
            const filename = `${root}/elements/${entry}.json`;
            if (fs.existsSync(filename)) {
                this.metaTable.loadFromFile(filename);
                continue;
            }
            this.metaTable.loadFromObject(require(entry));
        }
        return this.metaTable;
    }
    static expandRelative(src, currentPath) {
        if (src[0] === '.') {
            return path.normalize(`${currentPath}/${src}`);
        }
        return src;
    }
    mergeInternal(config) {
        this.config = deepmerge(this.config, config);
        return this.config;
    }
    get() {
        return Object.assign({}, this.config);
    }
    getRules() {
        const rules = Object.assign({}, this.config.rules || {});
        for (const name in rules) {
            let options = rules[name];
            if (!Array.isArray(options)) {
                options = [options, {}];
            }
            else if (options.length === 1) {
                options = [options[0], {}];
            }
            options[0] = parseSeverity(options[0]);
            rules[name] = options;
        }
        return rules;
    }
    transform(filename) {
        const transformer = this.findTransformer(filename);
        if (transformer) {
            return transformer.fn(filename);
        }
        else {
            return [{
                    data: fs.readFileSync(filename, { encoding: 'utf8' }),
                    filename,
                    line: 1,
                    column: 1,
                }];
        }
    }
    findTransformer(filename) {
        return this.transformers.find((entry) => entry.pattern.test(filename));
    }
    precompileTransformers(transform) {
        return Object.entries(transform).map(([pattern, module]) => {
            return {
                pattern: new RegExp(pattern),
                fn: require(module.replace('<rootDir>', this.rootDir)),
            };
        });
    }
    findRootDir() {
        let current = process.cwd();
        for (;;) {
            const search = path.join(current, 'package.json');
            if (fs.existsSync(search)) {
                return current;
            }
            const child = current;
            current = path.dirname(current);
            if (current === child) {
                break;
            }
        }
        return process.cwd();
    }
}
Config.SEVERITY_DISABLED = 0;
Config.SEVERITY_WARN = 1;
Config.SEVERITY_ERROR = 2;
exports.Config = Config;
