"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../config");
const lexer_1 = require("../lexer");
const parser_1 = require("../parser");
const reporter_1 = require("../reporter");
const rule_1 = require("../rule");
class Engine {
    constructor(config, ParserClass) {
        this.report = new reporter_1.Reporter();
        this.config = config;
        this.ParserClass = ParserClass;
    }
    lint(sources) {
        const rules = this.config.getRules();
        for (const source of sources) {
            const parser = new this.ParserClass(this.config);
            for (const name in rules) {
                const data = rules[name];
                Engine.loadRule(name, data, parser, this.report);
            }
            try {
                parser.parseHtml(source);
            }
            catch (e) {
                if (e instanceof lexer_1.InvalidTokenError) {
                    this.reportError(e.message, e.location);
                }
                else {
                    throw e;
                }
            }
        }
        return this.report.save();
    }
    dumpEvents(source) {
        const parser = new parser_1.Parser(this.config);
        const lines = [];
        parser.on('*', (event, data) => {
            lines.push({ event, data });
        });
        source.forEach(src => parser.parseHtml(src));
        return lines;
    }
    dumpTokens(source) {
        const lexer = new lexer_1.Lexer();
        const lines = [];
        for (const src of source) {
            for (const token of lexer.tokenize(src)) {
                const data = token.data ? token.data[0] : null;
                lines.push({
                    token: lexer_1.TokenType[token.type],
                    data: data,
                    location: `${token.location.filename}:${token.location.line}:${token.location.column}`,
                });
            }
        }
        return lines;
    }
    dumpTree(source) {
        const parser = new parser_1.Parser(this.config);
        const dom = parser.parseHtml(source[0]);
        const lines = [];
        function decoration(node) {
            let output = '';
            if (node.hasAttribute('id')) {
                output += `#${node.getAttribute('id')}`;
            }
            if (node.hasAttribute('class')) {
                output += `.${node.classList.join('.')}`;
            }
            return output;
        }
        function writeNode(node, level, sibling) {
            if (level > 0) {
                const indent = '  '.repeat(level - 1);
                const l = node.children.length > 0 ? '┬' : '─';
                const b = sibling < (node.parent.children.length - 1) ? '├' : '└';
                lines.push(`${indent}${b}─${l} ${node.tagName}${decoration(node)}`);
            }
            else {
                lines.push(`(root)`);
            }
            node.children.forEach((child, index) => writeNode(child, level + 1, index));
        }
        writeNode(dom.root, 0, 0);
        return lines;
    }
    static loadRule(name, data, parser, report) {
        const [severity, options] = data;
        if (severity >= config_1.Config.SEVERITY_WARN) {
            let rule;
            try {
                const Class = require(`../rules/${name}`);
                rule = new Class(options);
                rule.name = rule.name || name;
            }
            catch (e) {
                rule = new class extends rule_1.Rule {
                    setup() {
                        this.name = name;
                        this.on('dom:load', () => {
                            this.report(null, `Definition for rule '${name}' was not found`);
                        });
                    }
                }(options);
            }
            rule.init(parser, report, severity);
            rule.setup();
        }
    }
    reportError(message, location) {
        this.report.addManual(location.filename, {
            ruleId: undefined,
            severity: config_1.Config.SEVERITY_ERROR,
            message: message,
            line: location.line,
            column: location.column,
        });
    }
}
exports.Engine = Engine;
